import axios from "axios";

const state = {
    lastFetch: null,
    categorias: [],
    productos: [],
    filtro: null,
};

const mutations = {
    setCategorias(state, categorias) {
        state.lastFetch = new Date();
        state.categorias = categorias;
    },
    setProductos(state, productos) {
        state.lastFetch = new Date();
        state.productos = productos;
    },
    setFiltro(state, filtro) {
        state.lastFetch = new Date();
        state.filtro = filtro;
    },
};

const actions = {
    async init({ dispatch }) {
        dispatch('getCategorias');
        dispatch('getProductos');
    },
    async getCategorias({ commit }) {
        const response = await axios.get('api/categorias');
        commit('setCategorias', response.data);
    },
    async getProductos({ commit }) {
        const response = await axios.get("/api/productos");
        commit('setFiltro', null);
        commit('setProductos', response.data.data);
    },
    async seleccionarCategoria({ dispatch }, { categoria }) {
        dispatch('filtrarProductos', { filtro: "categoria", valor: categoria });
    },
    async filtrarProductos({ commit }, { filtro, valor }) {
        const response = await axios.get("/api/productos", {
            params: { [filtro]: valor }
        });
        commit('setFiltro', { clave: filtro, valor: valor });
        commit('setProductos', response.data.data);
    }
};

export default {
    namespaced: true,
    state,
    mutations,
    actions,
};
